@@ -11,16 +11,17 @@ class SignType(Enum):
 
 @dataclasses.dataclass()
 class BaseAction(object):
-    sign_type: str = dataclasses.field(init=False)
     origin: str
-    domain: str = dataclasses.field(init=False)
+    sign_type: str = dataclasses.field(init=False)
+    chain_id: int = dataclasses.field(init=False)
+    user_addr: str = dataclasses.field(init=False)
+
     def __post_init__(self):
         pass
 
 
 @dataclasses.dataclass()
 class TransactionAction(BaseAction):
-    chain_id: int = dataclasses.field(init=False)
     transaction: dict
 
     def __post_init__(self):
@@ -30,9 +31,7 @@ class TransactionAction(BaseAction):
 
 
 @dataclasses.dataclass()
-class TextAction(BaseAction):
-    
-    chain_id: int
+class TextAction(BaseAction):    
     text: str
         
     def __post_init__(self):
@@ -43,7 +42,6 @@ class TextAction(BaseAction):
 @dataclasses.dataclass()
 class TypedDataAction(BaseAction):
 
-    chain_id: int = dataclasses.field(init=False)
     typed_data: dict
     
     def __post_init__(self):
